@@ -92,6 +92,8 @@
             data.$gdbFrontend_runtimeControls_btn__t_btn = data.$gdbFrontend_runtimeControls_btn__t.find('.GDBFrontend_runtimeControls_btn_btn');
             data.$gdbFrontend_runtimeControls_btn__evaluate = data.$gdbFrontend_runtimeControls.find('.GDBFrontend_runtimeControls_btn__evaluate');
             data.$gdbFrontend_runtimeControls_btn__evaluate_btn = data.$gdbFrontend_runtimeControls_btn__evaluate.find('.GDBFrontend_runtimeControls_btn_btn');
+            data.$gdbFrontend_runtimeControls_btn__evaluateInNatıveWindow = data.$gdbFrontend_runtimeControls.find('.GDBFrontend_runtimeControls_btn__evaluateInNativeWindow');
+            data.$gdbFrontend_runtimeControls_btn__evaluateInNativeWindow_btn = data.$gdbFrontend_runtimeControls_btn__evaluateInNatıveWindow.find('.GDBFrontend_runtimeControls_btn_btn');
 
             data.$gdbFrontend_variablesExplorer__proto = $gdbFrontend.find('.GDBFrontend_variablesExplorerProto > .VariablesExplorer');
 
@@ -107,6 +109,10 @@
             
             data.$gdbFrontend_disassembly_title_buttons_button__openTab = $gdbFrontend.find('.GDBFrontend_disassembly_title_buttons_button__openTab');
 
+            data.$gdbFrontend_layout_top_themeMenu = data.$gdbFrontend.find('.GDBFrontend_layout_top_themeMenu');
+            data.$gdbFrontend_layout_top_themeMenu_items = data.$gdbFrontend_layout_top_themeMenu.find('.GDBFrontend_layout_top_themeMenu_items');
+            data.$gdbFrontend_layout_top_themeMenu_items_item_s = data.$gdbFrontend_layout_top_themeMenu_items.find('.GDBFrontend_layout_top_themeMenu_items_item');
+
             data.is_readonly = (t_init.parameters.is_readonly !== undefined) ? t_init.parameters.is_readonly: false;
             
             data.sourceOpener_current_dir = GDBFrontend.config.workdir ? GDBFrontend.config.workdir: '/';
@@ -252,6 +258,23 @@
                 if (parameters.expression) {
                     evaluater.evaluateExpression.evaluate({expression: parameters.expression});
                 }
+
+                return {evaluater: evaluater};
+            };
+
+            data.createEvaluaterOnNativeWindow = function (parameters) {
+                var nw = window.open(
+                    "/",
+                    "Evaluate Expression - " + Math.random().toString(36).substr(2, 9),
+                    "menubar=no,location=no,resizable=yes,scrollbars=no,status=no,toolbar=no,width=400,height=400,top=500,left=500"
+                );
+
+                nw.onload = function () {
+                    var evaluater = nw.GDBFrontend.components.gdbFrontend.createEvaluater(parameters).evaluater;
+                    
+                    evaluater.evaluateExpression.setOnNativewindow({is_on_native_window: true});
+                    evaluater.evaluateExpression.setFullScreen({is_fullscreen: true});
+                };
             };
             
             data.debug.getBreakpoint = function (parameters) {
@@ -1851,6 +1874,10 @@
             data.$gdbFrontend_runtimeControls_btn__evaluate_btn.on('click.GDBFrontend', function (event) {
                 data.createEvaluater();
             });
+            
+            data.$gdbFrontend_runtimeControls_btn__evaluateInNativeWindow_btn.on('click.GDBFrontend', function (event) {
+                data.createEvaluaterOnNativeWindow();
+            });
 
             data.$gdbFrontend_layout_bottom.on('mouseover.GDBFrontend', function (event) {
                 data.$gdbFrontend_terminalCloseBtn.show();
@@ -1868,6 +1895,26 @@
                 data.closeTerminal();
             });
 
+            data.$gdbFrontend_layout_top_themeMenu_items_item_s.on('click.GDBFrontend', function (event) {
+                var $item = $(this);
+                var theme_name = $item.attr('GDBFrontend_theme');
+                
+                $.ajax({
+                    url: '/api/switch-theme',
+                    cache: false,
+                    method: 'get',
+                    data: {
+                        theme: theme_name
+                    },
+                    success: function (result_json) {
+                    },
+                    error: function () {
+                        GDBFrontend.showMessageBox({text: 'An error occured.'});
+                        console.trace('An error occured.');
+                    }
+                });
+            });
+
             data.openTerminal = function (parameters) {
                 data.is_terminal_opened = true;
                 data.$gdbFrontend_layout_bottom.show();
